# DupLn
![Python Logo](https://www.python.org/static/community_logos/python-logo.png "Sample inline image")
![Python package](https://github.com/biojet1/dupln/workflows/Python%20package/badge.svg)
![Upload Python Package](https://github.com/biojet1/dupln/workflows/Upload%20Python%20Package/badge.svg)

[github.com/biojet1/dupln](https://github.com/biojet1/dupln)
[pypi.org/project/dupln](https://pypi.org/project/dupln/)

Hard link files with same content

# Install
```
> pip install dupln
```

# Usage
```
> python -m dupln link /tmp/he9wnq
INFO: Scanning: '/tmp/he9wnq'
INFO: Link: '/tmp/he9wnq/as/ci/i_letters' [2]
INFO: 	> '/tmp/he9wnq/as/cii_letters' - '/tmp/he9wnq/as/tmpt7g2i474' [1]
INFO: 	> '/tmp/he9wnq/as/ci/i_/letters' - '/tmp/he9wnq/as/ci/i_/tmpio986tvp' [0]
INFO: Link: '/tmp/he9wnq/as/ci/i_uppercase' [2]
INFO: 	> '/tmp/he9wnq/as/ci/i_/uppercase' - '/tmp/he9wnq/as/ci/i_/tmp8l1h75bq' [1]
INFO: 	> '/tmp/he9wnq/as/cii_uppercase' - '/tmp/he9wnq/as/tmp7_oy4o34' [0]
INFO: Link: '/tmp/he9wnq/as/cii_lowercase' [2]
INFO: 	> '/tmp/he9wnq/as/ci/i_/lowercase' - '/tmp/he9wnq/as/ci/i_/tmpedv27zfc' [1]
INFO: 	> '/tmp/he9wnq/as/ci/i_lowercase' - '/tmp/he9wnq/as/ci/tmptl35qpth' [0]
INFO: Link: '/tmp/he9wnq/di/gi/ts' [1]
INFO: 	> '/tmp/he9wnq/di/gits' - '/tmp/he9wnq/di/tmp9i_ptke2' [0]
INFO: Link: '/tmp/he9wnq/he/xd/igits' [2]
INFO: 	> '/tmp/he9wnq/he/xd/ig/its' - '/tmp/he9wnq/he/xd/ig/tmpv5dgokm8' [1]
INFO: 	> '/tmp/he9wnq/he/xdigits' - '/tmp/he9wnq/he/tmp893g6wni' [0]
INFO: Link: '/tmp/he9wnq/oc/td/igits' [2]
INFO: 	> '/tmp/he9wnq/oc/tdigits' - '/tmp/he9wnq/oc/tmpjc2r5ewb' [1]
INFO: 	> '/tmp/he9wnq/oc/td/ig/its' - '/tmp/he9wnq/oc/td/ig/tmp5pg29ym3' [0]
INFO: Link: '/tmp/he9wnq/pr/in/ta/ble' [2]
INFO: 	> '/tmp/he9wnq/pr/in/table' - '/tmp/he9wnq/pr/in/tmpovs_5mnh' [1]
INFO: 	> '/tmp/he9wnq/pr/intable' - '/tmp/he9wnq/pr/tmp8t0pg2xb' [0]
INFO: Link: '/tmp/he9wnq/pu/nctuation' [2]
INFO: 	> '/tmp/he9wnq/pu/nc/tuation' - '/tmp/he9wnq/pu/nc/tmpserkrny_' [1]
INFO: 	> '/tmp/he9wnq/pu/nc/tu/ation' - '/tmp/he9wnq/pu/nc/tu/tmp8dyokqr4' [0]
INFO: Link: '/tmp/he9wnq/wh/it/es/pace' [2]
INFO: 	> '/tmp/he9wnq/wh/itespace' - '/tmp/he9wnq/wh/tmp6j5r367o' [1]
INFO: 	> '/tmp/he9wnq/wh/it/espace' - '/tmp/he9wnq/wh/it/tmp5unofv67' [0]
INFO: Total disk_size 564b; files 35; inodes 35; linked 17; same_hash 9; same_size 8; size 1.1k; uniq_hash 9;
```
